@@ -5,7 +5,7 @@ package Mojolicious::Plugin::YamlConfig;
 
 use base 'Mojolicious::Plugin::JSONConfig';
 
-our $VERSION = '0.1.8';
+our $VERSION = '0.2.0';
 
 sub register {
     my ( $self, $app, $conf ) = @_;
@@ -32,9 +32,9 @@ sub parse {
     $content = $self->render($content, $file, $conf, $app);
 
     my @broken = qw(YAML YAML::Old YAML::Tiny);
-    if (grep { $class eq $_ } @broken) {
+    unless (grep { $class eq $_ } @broken) {
         # they are broken *sigh*
-        $content = Encode::decode('UTF-8', $content);
+        $content = Encode::encode('UTF-8', $content);
     }
 
     $config = eval $class.'::Load($content)';
